#[non_exhaustive]pub struct ListPreparedStatementsInput {
pub work_group: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.work_group: Option<String>The workgroup to list the prepared statements for.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
max_results: Option<i32>The maximum number of results to return in this request.
Implementations
Sourceimpl ListPreparedStatementsInput
impl ListPreparedStatementsInput
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The workgroup to list the prepared statements for.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in this request.
Sourceimpl ListPreparedStatementsInput
impl ListPreparedStatementsInput
Sourcepub fn builder() -> ListPreparedStatementsInputBuilder
pub fn builder() -> ListPreparedStatementsInputBuilder
Creates a new builder-style object to manufacture ListPreparedStatementsInput.