#[non_exhaustive]pub struct ListPreparedStatementsOutput {
pub prepared_statements: Option<Vec<PreparedStatementSummary>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.prepared_statements: Option<Vec<PreparedStatementSummary>>The list of prepared statements for the workgroup.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Implementations
Sourceimpl ListPreparedStatementsOutput
impl ListPreparedStatementsOutput
Sourcepub fn prepared_statements(&self) -> &[PreparedStatementSummary]
pub fn prepared_statements(&self) -> &[PreparedStatementSummary]
The list of prepared statements for the workgroup.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .prepared_statements.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourceimpl ListPreparedStatementsOutput
impl ListPreparedStatementsOutput
Sourcepub fn builder() -> ListPreparedStatementsOutputBuilder
pub fn builder() -> ListPreparedStatementsOutputBuilder
Creates a new builder-style object to manufacture ListPreparedStatementsOutput.